#[non_exhaustive]pub enum FairOrder {
Lifo,
Fifo,
}Expand description
The order of which Acquire should enter the queue.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Lifo
Last in, first out. Increases tail latencies, but can have better average performance.
Fifo
First in, first out. Fairer option, but can have cascading failures if queue processing is slow.